
% This program should not be run directly. It is called by other programs
% Assumption: x,t,n,p,L, Nw1, Nw2, dt, As and N are defined

% Spectrogram
wf=hanning(Nw1);
x1=[zeros((Nw1-1)/2,1);x;zeros((Nw1-1)/2,1)];
tau=0:Nw1-1;
SP=zeros(Nw2,N);
for k=1:N
    xx=x1(k+tau).*wf;
    SP(:,k)=fftshift(abs(fft(xx,Nw2)/Nw2).^2);
end


% S-method
wf=hanning(Nw2);
x1=[zeros((Nw2-1)/2,1);x;zeros((Nw2-1)/2,1)];
tau=0:Nw2-1;
ST=zeros(Nw2,N);
for k=1:N
    xx=x1(k+tau).*wf;
    ST(:,k)=fftshift(fft(xx))/Nw2;
end
SM=abs(ST).^2;
for m=1:L
    SM(1+m:Nw2-m,:)=SM(1+m:Nw2-m,:)+2*real(ST(1+2*m:Nw2,:).*conj(ST(1:Nw2-2*m,:)));
end



Al=0:1:179;
R1a=radon(SP,Al);
R2a=radon(SM,Al);
subplot(6,2,4)
imagesc(R2a)
axis xy
% axis square
set(gca,'Xtick',[],'Ytick',[])
ylabel('Radon Transform')
xlabel('angle from 0 to 180 degrees')
text(size(R1a,2),size(R1a,1),'(d) ^ ','Color',[1,1,1],'HorizontalAlignment','right','VerticalAlignment','top','FontWeight','bold')

subplot(6,2,3)
imagesc(R1a)
axis xy
% axis square
set(gca,'Xtick',[],'Ytick',[])
ylabel('Radon Transform')
xlabel('angle from 0 to 180 degrees')
text(size(R2a,2),size(R2a,1),'(c) ^ ','Color',[1,1,1],'HorizontalAlignment','right','VerticalAlignment','top','FontWeight','bold')





%IRT Calculation
% Inverse Radon and measures
Na=length(As);
% try
%     load M12
%     load NonExsistentFile % uncomment this line to always calculate measures
%     disp('Warning: Measure data are loaded from file M12.mat!')
%     disp('         Delete file M12.mat if recalculation is needed.')
% catch
M1=zeros(Na,1);
M2=zeros(Na,1);
for k=1:Na
    IR=iradon(SP,180/pi*As(k)*t,Nw2);
    IR=(IR+abs(IR))/2;
%     EIR=sqrt(sum(sum(IR.^2)));
    %         M1(k)=(sum(sum(abs(IR).^(1/p))).^p)/EIR;
    M1(k)=max(max(IR));
    IR=iradon(SM,180/pi*As(k)*t,Nw2);
    IR=(IR+abs(IR))/2;
%     EIR=sqrt(sum(sum(IR.^2)));
    %         M2(k)=(sum(sum(abs(IR).^(1/p))).^p)/EIR;
    M2(k)=max(max(IR));
end
%     save M12 M1 M2
%     disp('Measure data are calculated and saved in file M12.mat!')
% end

% Find minima positions and corresponding alpha
[ddd,mp1]=max(M1);
[ddd,mp2]=max(M2);

Alpha1=As(mp1)
Alpha2=As(mp2)

IR1a=iradon(SP,180/pi*Alpha1*t,Nw2);
IR2a=iradon(SM,180/pi*Alpha2*t,Nw2);

IR1b=iradon(SP,180/pi*7*t,Nw2);
IR2b=iradon(SM,180/pi*10*t,Nw2);

IntF=1; % interpolation factor

IR1a=interp2(IR1a,IntF,'cubic');
IR1b=interp2(IR1b,IntF,'cubic');
IR2a=interp2(IR2a,IntF,'cubic');
IR2b=interp2(IR2b,IntF,'cubic');

IntF=2^IntF;

IR1a=abs(IR1a);
IR1b=abs(IR1b);
IR2a=abs(IR2a);
IR2b=abs(IR2b);

% SM=SM1;
% SP=SP1;
% t=t1;
% Displaying results

f=(-(Nw2-1)/2:(Nw2-1)/2)/Nw2/dt;

subplot(6,2,1)
imagesc(t,f,SP)
axis xy
xlabel('time')
ylabel('frequency')
title('Spectrogram')
text(max(t),max(f),'(a) ^ ','Color',[1,1,1],'HorizontalAlignment','right','VerticalAlignment','top','FontWeight','bold')

subplot(6,2,2)
imagesc(t,f,SM+abs(SM))
axis xy
xlabel('time')
ylabel('frequency')
title('S-method')
text(max(t),max(f),'(b) ^ ','Color',[1,1,1],'HorizontalAlignment','right','VerticalAlignment','top','FontWeight','bold')


subplot(6,2,5)
imagesc(IR1a)
axis xy
% axis square
set(gca,'Xtick',[],'Ytick',[])
ylabel(['IRT for \alpha_ =_ ',num2str(Alpha1)])
[ddd,pp1]=max(IR1a);
[ddd,px]=max(ddd);
py=pp1(px);
p0=(size(IR1a,1)+1)/2;
hold on
h=plot(linspace(p0,px,7),linspace(p0,py,7),'wo');
set(h,'MarkerSize',2,'MarkerFaceColor',[1,1,1],'MarkerEdgeColor',[0,0,0])
%plot(p0,p0,'r.')
hold off
text(p0,p0,'A_m^ , \theta_m','VerticalAlignment','top','HorizontalAlignment','center','Color',[1,1,1])
text(size(IR1a,2),size(IR1a,1),'(e) ^ ','Color',[1,1,1],'HorizontalAlignment','right','VerticalAlignment','top','FontWeight','bold')



subplot(6,2,6)
imagesc(IR2a)
axis xy
% axis square
set(gca,'Xtick',[],'Ytick',[])
ylabel(['IRT for \alpha_ =_ ',num2str(Alpha1)])
[ddd,pp1]=max(IR2a);
[ddd,px]=max(ddd);
py=pp1(px);
p0=(size(IR2a,1)+1)/2;
hold on
h=plot(linspace(p0,px,7),linspace(p0,py,7),'wo');
set(h,'MarkerSize',2,'MarkerFaceColor',[1,1,1],'MarkerEdgeColor',[0,0,0])
%plot(p0,p0,'r.')
hold off
text(p0,p0,'A_m^ , \theta_m','VerticalAlignment','top','HorizontalAlignment','center','Color',[1,1,1])
text(size(IR2a,2),size(IR2a,1),'(f) ^ ','Color',[1,1,1],'HorizontalAlignment','right','VerticalAlignment','top','FontWeight','bold')


